All Classes and Interfaces

Class
Description
 
 
 
The active rqueue backend.
Raised when a web/dashboard operation is invoked against a backend that does not implement the primitive it requires (e.g.
 
 
 
 
 
 
 
 
 
 
A context that supports getValue method.
Context middleware allows us to set context for the running job, context could be any thing like putting user information for permission check, initiating some transaction.
 
 
 
 
 
 
 
 
An implementation of Context, a context is immutable object, it can not be modified, it allows only create new context from existing context and get value from this context.
 
Rqueue message converter
 
Stores all registered queue details
 
 
 
Implementation of the TaskExecutionBackOff class, that increases the delay exponentially at the specified rate.
Implementation of the TaskExecutionBackOff class, that always return the same value, except if number of failures have increased too high.
A converter to turn the payload of a Message from serialized form to a typed String and vice versa.
 
 
 
 
 
On each execution Rqueue creates a job to track it's status and execution progress.
 
 
 
JsonMessageConverter tries to convert to JSON and from JSON to object.
Whenever a lock can not be acquired cause some other process/thread is holding lock then this error would be thrown.
Lock middleware can be used for locking purpose Use cases:
A simple logging middleware that logs queue and job id for visibility
Internal SPI.
 
 
Backend-shaped browsing primitives consumed by the dashboard's queue-detail and data-explorer pages.
MessageConverterProvider provides an interface to return message converter that will be used across Rqueue.
 
 
Indicates that an annotated class is a message listener
 
 
 
 
This interface can be used to take some action whenever a message is processed
 
 
 
RqueueMetrics provides all possible configurations available in Rqueue library for metrics.
 
Middlewares are used in a chain, at the end of chain listener method is called.
 
 
 
 
Spring Condition that matches when the active rqueue backend is Backend.NATS.
 
 
 
 
Permission middleware allows to check whether some permission is there for a given job,
 
 
 
 
A profile middleware that measures the execution time of a job, a more sophisticated profiler middleware can report latency to New Relic, Datadog, or use Micrometer to report latency or any other data.
 
 
 
Queue counter counts the different types of events related to a queue.
Configuration and metadata for an Rqueue listener.
This exception is raised, when a queue is not registered in EndpointRegistry, to register a queue use RqueueEndpointManager.registerQueue(String, String...)
 
 
 
 
 
 
 
 
 
 
 
Spring Condition that matches when the active rqueue backend is Backend.REDIS.
 
This uses Redis as backend for locking, using SETNX a lock is acquired.
Default MessageBroker implementation that delegates to the existing Redis-backed code path via RqueueMessageTemplate.
 
 
 
 
 
 
 
 
 
 
RqueueSerDes implementation backed by a Jackson ObjectMapper.
 
 
This event is generated at RqueueContainer startup and shutdown.
 
Rqueue counter counts the different types of events related to a queue.
 
 
Rqueue end point manager, manages the end point related to Rqueue.
 
This event is generated once a message is consumed.
This designated any public method as listener given the containing method is also annotated with RqueueListener.
 
 
 
 
Annotation for mapping a method/class onto message-handling methods by matching to the message queue.
This is a base configuration class for Rqueue, that is used in Spring and Spring boot Rqueue libs for configurations.
 
Envelope for a message being processed through Rqueue.
RqueueMessageEnqueuer enqueue message to Redis queue using different mechanism.
 
Invokes RqueueListener-annotated listener methods and routes exceptions to RqueueHandler-annotated error handlers.
 
 
Container providing asynchronous behaviour for Rqueue message listeners.
Rqueue Message Manager manages messages related to a queue.
 
 
 
Rqueue message template is used to send messages
RqueueMessageTemplate is the core of the Rqueue, this deals with Redis calls.
 
RqueueMetrics register metrics related to queue.
 
 
 
 
 
 
 
Backend-agnostic provider of queue-depth metrics.
 
 
 
 
 
Serialization / deserialization contract used by the NATS backend.
 
 
 
 
 
 
 
 
 
 
 
Backend-agnostic worker registry.
 
 
 
A Factory class which can be used to create RqueueMessageListenerContainer object.
 
 
 
Per-subscriber row rendered by the queue-detail "Subscribers" section.
Per-subscriber row surfaced by MessageBroker.subscribers(com.github.sonus21.rqueue.listener.QueueDetail) for the queue-detail dashboard.
 
 
 
 
 
 
Row in the queue-detail "Terminal Storage" table — one entry per shared bucket (COMPLETED messages, DEAD letter queues).
 
 
waitFor method wait for some event to occur.
A middleware extension that allows implementation to provide different types of delay in different case.
 
 
 
 
 
Backend-shaped persistence primitives for the worker registry.