Package com.github.sonus21.rqueue.config
package com.github.sonus21.rqueue.config
-
ClassDescriptionThe active rqueue backend.RqueueMetrics provides all possible configurations available in Rqueue library for metrics.Spring
Conditionthat matches when the active rqueue backend isBackend.NATS.SpringConditionthat matches when the active rqueue backend isBackend.REDIS.This is a base configuration class for Rqueue, that is used in Spring and Spring boot Rqueue libs for configurations.A Factory class which can be used to createRqueueMessageListenerContainerobject.