Interface MessageConverterProvider
- All Known Implementing Classes:
DefaultMessageConverterProvider
public interface MessageConverterProvider
MessageConverterProvider provides an interface to return message converter that will be used
across Rqueue.
Using message converter using other way is discouraged as it can cause problem in some flow.
NOTE: Any custom implementation can expect targetClass being null, if targetClass is
null then it can return the string it self. See implementation of
JsonMessageConverter.fromMessage(Message, Class)
- See Also:
-
Method Summary
Modifier and TypeMethodDescriptionorg.springframework.messaging.converter.MessageConverterThe returned message converter can be of any type
-
Method Details
-
getConverter
org.springframework.messaging.converter.MessageConverter getConverter()The returned message converter can be of any type- Returns:
- MessageConverter object
-