Package com.github.sonus21.rqueue.exception
package com.github.sonus21.rqueue.exception
-
ExceptionsClassDescriptionRaised when a web/dashboard operation is invoked against a backend that does not implement the primitive it requires (e.g.Whenever a lock can not be acquired cause some other process/thread is holding lock then this error would be thrown.This exception is raised, when a queue is not registered in
EndpointRegistry, to register a queue useRqueueEndpointManager.registerQueue(String, String...)