Serialized Form
-
Package com.github.sonus21.rqueue.core
-
Class com.github.sonus21.rqueue.core.RqueueMessage
class RqueueMessage extends SerializableBase implements Serializable- serialVersionUID:
- -3488860960637488519L
-
Serialized Fields
-
failureCount
int failureCount
-
id
String id
-
message
String message
JSON encoded message, this message can be converted to actual object with the help ofRqueueMessageUtils.convertMessageToObject(com.github.sonus21.rqueue.core.RqueueMessage, org.springframework.messaging.converter.MessageConverter)method -
messageHeaders
org.springframework.messaging.MessageHeaders messageHeaders
-
period
long period
-
processAt
long processAt
-
queuedTime
long queuedTime
-
queueName
String queueName
-
reEnqueuedAt
Long reEnqueuedAt
-
retryCount
Integer retryCount
-
sourceQueueFailureCount
int sourceQueueFailureCount
-
sourceQueueName
String sourceQueueName
-
-
-
Package com.github.sonus21.rqueue.exception
-
Exception com.github.sonus21.rqueue.exception.BackendCapabilityException
class BackendCapabilityException extends RuntimeException implements Serializable- serialVersionUID:
- 1L
-
Exception com.github.sonus21.rqueue.exception.DuplicateMessageException
class DuplicateMessageException extends RuntimeException implements Serializable -
Exception com.github.sonus21.rqueue.exception.LockCanNotBeAcquired
class LockCanNotBeAcquired extends RuntimeException implements Serializable- serialVersionUID:
- 598739372785907190L
-
Exception com.github.sonus21.rqueue.exception.OverrideException
class OverrideException extends RuntimeException implements Serializable- serialVersionUID:
- 598739372785907190L
-
Exception com.github.sonus21.rqueue.exception.ProcessingException
class ProcessingException extends Exception implements Serializable- serialVersionUID:
- 9003794852942108696L
-
Serialized Fields
-
data
Object data
-
-
Exception com.github.sonus21.rqueue.exception.QueueDoesNotExist
class QueueDoesNotExist extends RuntimeException implements Serializable- serialVersionUID:
- 598739372785907190L
-
Exception com.github.sonus21.rqueue.exception.TimedOutException
class TimedOutException extends Exception implements Serializable- serialVersionUID:
- 132943639600997783L
-
Exception com.github.sonus21.rqueue.exception.UnknownSwitchCase
class UnknownSwitchCase extends RuntimeException implements Serializable- serialVersionUID:
- -363842614000049763L
-
-
Package com.github.sonus21.rqueue.listener
-
Class com.github.sonus21.rqueue.listener.QueueDetail
class QueueDetail extends SerializableBase implements Serializable- serialVersionUID:
- 9153752084449974622L
-
Serialized Fields
-
active
boolean active
-
batchSize
int batchSize
-
completedQueueName
String completedQueueName
-
concurrency
Concurrency concurrency
-
consumerName
String consumerName
-
deadLetterConsumerEnabled
boolean deadLetterConsumerEnabled
-
deadLetterQueueName
String deadLetterQueueName
-
doNotRetry
Set<Class<? extends Throwable>> doNotRetry
-
name
String name
-
numRetry
int numRetry
-
priority
Map<String,
Integer> priority -
priorityGroup
String priorityGroup
-
processingQueueChannelName
String processingQueueChannelName
-
processingQueueName
String processingQueueName
-
queueName
String queueName
-
scheduledQueueChannelName
String scheduledQueueChannelName
-
scheduledQueueName
String scheduledQueueName
-
systemGenerated
boolean systemGenerated
-
type
QueueType type
-
visibilityTimeout
long visibilityTimeout
-
-
-
Package com.github.sonus21.rqueue.models
-
Class com.github.sonus21.rqueue.models.Concurrency
class Concurrency extends SerializableBase implements Serializable- serialVersionUID:
- 3165194419314698068L
-
Serialized Fields
-
max
int max
-
min
int min
-
-
Class com.github.sonus21.rqueue.models.MinMax
class MinMax extends SerializableBase implements Serializable- serialVersionUID:
- 455990603344829053L
-
Serialized Fields
-
max
T extends Serializable max
-
min
T extends Serializable min
-
-
Class com.github.sonus21.rqueue.models.PubSubMessage
class PubSubMessage extends SerializableBase implements Serializable- serialVersionUID:
- 780914041036616260L
-
Serialized Fields
-
data
Serializable data
-
senderId
String senderId
-
-
Class com.github.sonus21.rqueue.models.SerializableBase
class SerializableBase extends Object implements Serializable
-
-
Package com.github.sonus21.rqueue.models.db
-
Class com.github.sonus21.rqueue.models.db.CheckinMessage
class CheckinMessage extends SerializableBase implements Serializable- serialVersionUID:
- 4727068901984917510L
-
Serialized Fields
-
at
long at
-
message
Serializable message
-
-
Class com.github.sonus21.rqueue.models.db.DeadLetterQueue
class DeadLetterQueue extends SerializableBase implements Serializable- serialVersionUID:
- 2632111672508854121L
-
Serialized Fields
-
consumerEnabled
boolean consumerEnabled
-
name
String name
-
-
Class com.github.sonus21.rqueue.models.db.Execution
class Execution extends SerializableBase implements Serializable- serialVersionUID:
- 3893537050761142817L
-
Serialized Fields
-
endTime
long endTime
-
error
String error
-
exception
Throwable exception
-
startTime
long startTime
-
status
ExecutionStatus status
-
-
Class com.github.sonus21.rqueue.models.db.JobRunTime
class JobRunTime extends SerializableBase implements Serializable- serialVersionUID:
- 6219118148061766036L
-
Serialized Fields
-
jobCount
long jobCount
-
max
long max
-
min
long min
-
totalExecutionTime
long totalExecutionTime
-
-
Class com.github.sonus21.rqueue.models.db.MessageMetadata
class MessageMetadata extends SerializableBase implements Serializable- serialVersionUID:
- 4200184682879443328L
-
Serialized Fields
-
deleted
boolean deleted
-
deletedOn
Long deletedOn
-
id
String id
-
rqueueMessage
RqueueMessage rqueueMessage
-
status
MessageStatus status
-
totalExecutionTime
long totalExecutionTime
-
updatedOn
long updatedOn
-
-
Class com.github.sonus21.rqueue.models.db.QueueConfig
class QueueConfig extends SerializableBase implements Serializable- serialVersionUID:
- 2644813429709395582L
-
Serialized Fields
-
completedQueueName
String completedQueueName
-
concurrency
MinMax<Integer> concurrency
-
createdOn
Long createdOn
-
deadLetterQueues
List<DeadLetterQueue> deadLetterQueues
-
deleted
boolean deleted
-
deletedOn
Long deletedOn
-
id
String id
-
name
String name
-
numRetry
int numRetry
-
paused
boolean paused
-
priority
Map<String,
Integer> priority -
priorityGroup
String priorityGroup
-
processingQueueName
String processingQueueName
-
queueName
String queueName
-
scheduledQueueName
String scheduledQueueName
-
systemGenerated
boolean systemGenerated
-
updatedOn
Long updatedOn
-
visibilityTimeout
long visibilityTimeout
-
-
Class com.github.sonus21.rqueue.models.db.QueueStatistics
class QueueStatistics extends SerializableBase implements Serializable- serialVersionUID:
- -4931206278693499365L
-
Serialized Fields
-
createdOn
Long createdOn
-
id
String id
-
jobRunTime
Map<String,
JobRunTime> jobRunTime -
startEpochDate
Long startEpochDate
-
tasksDiscarded
Map<String,
Long> tasksDiscarded -
tasksMovedToDeadLetter
Map<String,
Long> tasksMovedToDeadLetter -
tasksRetried
Map<String,
Long> tasksRetried -
tasksSuccessful
Map<String,
Long> tasksSuccessful -
updatedOn
Long updatedOn
-
-
Class com.github.sonus21.rqueue.models.db.RqueueJob
class RqueueJob extends SerializableBase implements Serializable- serialVersionUID:
- 6219118148061766036L
-
Serialized Fields
-
checkins
List<CheckinMessage> checkins
-
createdAt
long createdAt
-
error
String error
-
exception
Throwable exception
-
executions
List<Execution> executions
-
id
String id
-
lastCheckinAt
long lastCheckinAt
-
messageId
String messageId
-
messageMetadata
MessageMetadata messageMetadata
-
rqueueMessage
RqueueMessage rqueueMessage
-
status
JobStatus status
-
updatedAt
long updatedAt
-
-
-
Package com.github.sonus21.rqueue.models.event
-
Class com.github.sonus21.rqueue.models.event.RqueueBootstrapEvent
class RqueueBootstrapEvent extends org.springframework.context.ApplicationEvent implements Serializable- serialVersionUID:
- 1955427920805054136L
-
Serialized Fields
-
start
boolean start
-
-
Class com.github.sonus21.rqueue.models.event.RqueueExecutionEvent
class RqueueExecutionEvent extends org.springframework.context.ApplicationEvent implements Serializable- serialVersionUID:
- -7762050873209497221L
-
Class com.github.sonus21.rqueue.models.event.RqueuePubSubEvent
class RqueuePubSubEvent extends SerializableBase implements Serializable-
Serialized Fields
-
message
String message
-
senderId
String senderId
-
type
PubSubType type
-
-
-
Class com.github.sonus21.rqueue.models.event.RqueueQueuePauseEvent
class RqueueQueuePauseEvent extends org.springframework.context.ApplicationEvent implements Serializable-
Serialized Fields
-
paused
boolean paused
-
queue
String queue
-
-
-
-
Package com.github.sonus21.rqueue.models.registry
-
Class com.github.sonus21.rqueue.models.registry.RqueueWorkerInfo
class RqueueWorkerInfo extends SerializableBase implements Serializable -
Class com.github.sonus21.rqueue.models.registry.RqueueWorkerPollerMetadata
class RqueueWorkerPollerMetadata extends SerializableBase implements Serializable- serialVersionUID:
- -8612115593908071754L
-
Class com.github.sonus21.rqueue.models.registry.RqueueWorkerPollerView
class RqueueWorkerPollerView extends SerializableBase implements Serializable- serialVersionUID:
- 7432122245407288494L
-
Serialized Fields
-
capacityExhaustedCount
long capacityExhaustedCount
-
consumerName
String consumerName
-
host
String host
-
lastCapacityExhaustedAge
String lastCapacityExhaustedAge
-
lastCapacityExhaustedAt
Long lastCapacityExhaustedAt
-
lastMessageAge
String lastMessageAge
-
lastMessageAt
Long lastMessageAt
-
lastPollAge
String lastPollAge
-
lastPollAt
long lastPollAt
-
pid
String pid
-
queue
String queue
-
status
String status
-
workerId
String workerId
-
-
Class com.github.sonus21.rqueue.models.registry.RqueueWorkerView
class RqueueWorkerView extends SerializableBase implements Serializable- serialVersionUID:
- 4777550203661409019L
-
-
Package com.github.sonus21.rqueue.models.request
-
Class com.github.sonus21.rqueue.models.request.ChartDataRequest
class ChartDataRequest extends SerializableBase implements Serializable- serialVersionUID:
- 7727090378318819986L
-
Serialized Fields
-
aggregationType
AggregationType aggregationType
-
dateTypes
List<ChartDataType> dateTypes
-
number
int number
-
queue
String queue
-
type
ChartType type
-
-
Class com.github.sonus21.rqueue.models.request.DataDeleteRequest
class DataDeleteRequest extends SerializableBase implements Serializable -
Class com.github.sonus21.rqueue.models.request.DataTypeRequest
class DataTypeRequest extends SerializableBase implements Serializable-
Serialized Fields
-
name
@NotEmpty String name
-
-
-
Class com.github.sonus21.rqueue.models.request.DateViewRequest
class DateViewRequest extends SerializableBase implements Serializable -
Class com.github.sonus21.rqueue.models.request.MessageDeleteRequest
class MessageDeleteRequest extends SerializableBase implements Serializable -
Class com.github.sonus21.rqueue.models.request.MessageEnqueueRequest
class MessageEnqueueRequest extends SerializableBase implements Serializable -
Class com.github.sonus21.rqueue.models.request.MessageMoveRequest
class MessageMoveRequest extends Object implements Serializable- serialVersionUID:
- -5105668034442269108L
-
Class com.github.sonus21.rqueue.models.request.PauseUnpauseQueueRequest
class PauseUnpauseQueueRequest extends DataTypeRequest implements Serializable-
Serialized Fields
-
pause
boolean pause
-
-
-
Class com.github.sonus21.rqueue.models.request.QueueExploreRequest
class QueueExploreRequest extends SerializableBase implements Serializable-
Serialized Fields
-
consumerName
String consumerName
Optional consumer / subscriber name. When set on Limits-retention streams the broker starts the peek from that consumer's next undelivered sequence instead of the stream's first sequence, so the explorer shows messages that are still pending for this specific consumer rather than the entire retained window. -
itemPerPage
int itemPerPage
-
name
@NotEmpty String name
-
pageNumber
int pageNumber
-
src
@NotEmpty String src
-
type
@NotNull DataType type
-
-
-
-
Package com.github.sonus21.rqueue.models.response
-
Class com.github.sonus21.rqueue.models.response.Action
class Action extends SerializableBase implements Serializable- serialVersionUID:
- 7809140410366162600L
-
Serialized Fields
-
description
String description
-
type
ActionType type
-
-
Class com.github.sonus21.rqueue.models.response.BaseResponse
class BaseResponse extends SerializableBase implements Serializable- serialVersionUID:
- 4830863373464370840L
-
Serialized Fields
-
code
int code
-
message
String message
-
-
Class com.github.sonus21.rqueue.models.response.BooleanResponse
class BooleanResponse extends BaseResponse implements Serializable- serialVersionUID:
- 3137908352960413849L
-
Serialized Fields
-
value
boolean value
-
-
Class com.github.sonus21.rqueue.models.response.ChartDataResponse
class ChartDataResponse extends BaseResponse implements Serializable- serialVersionUID:
- -7881568871822217801L
-
Class com.github.sonus21.rqueue.models.response.DataSelectorResponse
class DataSelectorResponse extends BaseResponse implements Serializable -
Class com.github.sonus21.rqueue.models.response.DataViewResponse
class DataViewResponse extends BaseResponse implements Serializable- serialVersionUID:
- -8359552138158857044L
-
Serialized Fields
-
actions
List<Action> actions
-
headers
List<String> headers
-
hideCronJobs
boolean hideCronJobs
Optional UI hint set by the dashboard service when the activeMessageBrokerdoes not support cron jobs (seeCapabilities#supportsCronJobs). Whentruethe frontend should hide / grey out cron-style management. Additive and defaults tofalse. -
hideScheduledPanel
boolean hideScheduledPanel
Optional UI hint set by the dashboard service when the activeMessageBrokerdoes not support scheduled-queue introspection (seeCapabilities#supportsScheduledIntrospection). Whentruethe frontend should hide / grey out the scheduled-queue panel. Additive and defaults tofalseso the Redis backend's existing behavior is unchanged. -
rows
List<TableRow> rows
-
-
Class com.github.sonus21.rqueue.models.response.MessageMoveResponse
class MessageMoveResponse extends BooleanResponse implements Serializable- serialVersionUID:
- 4070425131282033429L
-
Serialized Fields
-
numberOfMessageTransferred
int numberOfMessageTransferred
-
-
Class com.github.sonus21.rqueue.models.response.RedisDataDetail
class RedisDataDetail extends SerializableBase implements Serializable- serialVersionUID:
- 1056616946630817927L
-
Serialized Fields
-
approximate
boolean approximate
Indicates thatRedisDataDetail.sizeis an approximation rather than an exact count. NATS Limits-retention streams compute pending size fromlastSeq - min(delivered.streamSeq)across durable consumers, which is approximate when filter subjects or per-consumer positions diverge. Templates render the size with a~prefix when this is set. -
consumerName
String consumerName
Optional consumer name when the row represents a single subscriber's view of a shared stream (e.g. NATS Limits-retention streams). Renders next to the stream name in the "Name" column so each durable consumer's lag is visible separately. -
name
String name
-
size
long size
-
type
DataType type
-
typeLabel
String typeLabel
Backend-aware human-readable label for theRedisDataDetail.type. The legacy templates surface this directly so deployments can display "Queue" / "Stream" on NATS instead of Redis-shaped "LIST" / "ZSET" tokens. When unset, templates default totype.name().
-
-
Class com.github.sonus21.rqueue.models.response.RowColumnMeta
class RowColumnMeta extends SerializableBase implements Serializable- serialVersionUID:
- 7727947329124106340L
-
Serialized Fields
-
data
Serializable data
-
type
RowColumnMetaType type
-
-
Class com.github.sonus21.rqueue.models.response.StringResponse
class StringResponse extends BaseResponse implements Serializable- serialVersionUID:
- -5110084277095370843L
-
Serialized Fields
-
val
String val
-
-
Class com.github.sonus21.rqueue.models.response.SubscriberRow
class SubscriberRow extends SerializableBase implements Serializable- serialVersionUID:
- 1L
-
Serialized Fields
-
consumerName
String consumerName
Logical handler name (resolved consumer name on NATS, listener bean#method on Redis). -
dataType
DataType dataType
Redis-shaped data type used for the explorer modal's pagination logic. -
host
String host
Host running the active worker, when known. -
inFlight
long inFlight
Messages delivered but not yet acknowledged by this subscriber. -
lastPollAge
String lastPollAge
Human-formatted "last poll age" — populated server-side for Pebble. -
lastPollAt
long lastPollAt
Epoch ms of the most recent poll observed for this subscriber. -
pending
long pending
Messages this subscriber is responsible for processing. For brokers with shared pools (Redis, NATS WorkQueue) this is the queue-wide pending count; for NATS Limits streams it's the per-consumernumPending. -
pendingShared
boolean pendingShared
Indicatespendingis a queue-wide aggregate, not this consumer's exclusive backlog. Templates render a "(shared)" hint when this is true. -
pid
String pid
PID of the active worker, when known (kept as String to mirror the worker registry). -
status
String status
Worker status: ACTIVE / STALE / UNKNOWN. -
storageName
String storageName
The underlying storage handle exposed to the message-explorer modal. -
typeLabel
String typeLabel
Backend-aware label, e.g. "Queue (Stream)" / "Stream consumer" / "List". -
workerCount
int workerCount
Number of distinct(JVM, consumer)heartbeats currently active in the worker registry — i.e. how many polling worker instances are attached to this consumer across the cluster. The row'sSubscriberRow.host/SubscriberRow.pid/SubscriberRow.lastPollAtfields describe only the most-recently polling instance, so the dashboard surfaces the total count separately. Thread-level fanout from@RqueueListener(concurrency = "10-20")lives inside a single instance and is not reflected here — the registry tracks heartbeats per JVM, not per thread.
-
-
Class com.github.sonus21.rqueue.models.response.Table
class Table extends BaseResponse implements Serializable- serialVersionUID:
- -7188146334911288456L
-
Class com.github.sonus21.rqueue.models.response.TableColumn
class TableColumn extends SerializableBase implements Serializable- serialVersionUID:
- -610454244824717486L
-
Serialized Fields
-
meta
List<RowColumnMeta> meta
-
type
TableColumnType type
-
value
Serializable value
-
-
Class com.github.sonus21.rqueue.models.response.TableRow
class TableRow extends SerializableBase implements Serializable- serialVersionUID:
- -1493539297572507490L
-
Serialized Fields
-
columns
List<TableColumn> columns
-
meta
List<RowColumnMeta> meta
-
-
Class com.github.sonus21.rqueue.models.response.TerminalStorageRow
class TerminalStorageRow extends SerializableBase implements Serializable- serialVersionUID:
- 1L
-
Serialized Fields
-
approximate
boolean approximate
truewhensizeis a best-effort estimate rather than an exact count. -
dataType
DataType dataType
Redis-shaped data type used by the explorer modal's pagination logic. -
size
long size
Number of messages currently in this bucket. Negative values render as "Queue-backed" (matches the existing data-detail semantics for DLQs whose consumer is enabled). -
storageName
String storageName
Underlying storage handle (e.g. Redis ZSET key, JetStream stream name). -
tab
NavTab tab
Tab category — COMPLETED / DEAD. Used for the "Bucket" column label. -
typeLabel
String typeLabel
Backend-aware label, e.g. "Completed (KV)" / "Dead Letter (Stream)" / "ZSET" / "LIST".
-
-