Package com.github.sonus21.rqueue.config
Class MetricsProperties
java.lang.Object
com.github.sonus21.rqueue.config.MetricsProperties
RqueueMetrics provides all possible configurations available in Rqueue library for metrics.
Rqueue can be configured to count the failure execution, total execution, and can have set of tags.
-
Nested Class Summary
Nested Classes -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanbooleangetMetricName(String name) io.micrometer.core.instrument.TagsGet Tags object that can be used in metric.voidsetMetricTags(io.micrometer.core.instrument.Tags tags)
-
Constructor Details
-
MetricsProperties
public MetricsProperties()
-
-
Method Details
-
getMetricTags
public io.micrometer.core.instrument.Tags getMetricTags()Get Tags object that can be used in metric. Tags can be either configured manually or using properties or XML file.- Returns:
- Tags object
-
setMetricTags
public void setMetricTags(io.micrometer.core.instrument.Tags tags) -
countExecution
public boolean countExecution() -
countFailure
public boolean countFailure() -
getMetricName
-