Package com.github.sonus21.rqueue.config
Class MetricsProperties
- java.lang.Object
-
- com.github.sonus21.rqueue.config.MetricsProperties
-
public abstract class MetricsProperties extends java.lang.ObjectRqueueMetrics provides all possible configurations available in Rqueue library for metrics.Rqueue can be configured to count the failure execution, total execution, and can have set of tags.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classMetricsProperties.Count
-
Constructor Summary
Constructors Constructor Description MetricsProperties()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description booleancountExecution()booleancountFailure()io.micrometer.core.instrument.TagsgetMetricTags()Get Tags object that can be used in metric.voidsetMetricTags(io.micrometer.core.instrument.Tags tags)
-
-
-
Method Detail
-
getMetricTags
public io.micrometer.core.instrument.Tags getMetricTags()
Get Tags object that can be used in metric. Tags can be either configured manually or using properties or XML file.- Returns:
- Tags object
-
setMetricTags
public void setMetricTags(io.micrometer.core.instrument.Tags tags)
-
countExecution
public boolean countExecution()
-
countFailure
public boolean countFailure()
-
-